@@ -17,6 +17,7 @@ from __future__ import annotations
 
 import dataclasses
 import email.utils
+import logging
 import random
 from datetime import date, datetime, timedelta, timezone
 from typing import Any
@@ -33,6 +34,8 @@ from . import (
     get_wrong_quotes,
 )
 
+logger = logging.getLogger(__name__)
+
 
 def get_module_info(*, hidden: bool = True) -> ModuleInfo:
     """Create and return the ModuleInfo for this module."""
@@ -183,6 +186,9 @@ class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
         quotes: tuple[WrongQuote, ...] = get_wrong_quotes(
             lambda wq: wq.rating > 1
         )
+        if not quotes:
+            logger.warning("No quotes available!")
+            return None
         count = len(quotes)
         index = random.randrange(0, count)
         for _ in range(count - 1):
@@ -211,7 +217,6 @@ class QuoteOfTheDayRss(QuoteOfTheDayBaseHandler):
 
     async def get(self, *, head: bool = False) -> None:
         """Handle GET requests."""
-        self.set_header("Content-Type", f"{self.content_type}; charset=UTF-8")
         if head:
             return
         today = datetime.now(tz=timezone.utc).date()
