@@ -1,5 +1,5 @@
 // @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt GNU-AGPL-3.0-or-later
-function startQuotes(currId,nextId){const thisQuoteId=[currId];const nextQuoteId=[nextId];const params=w.location.search;const nextButton=elById("next");const upvoteButton=elById("upvote");const downvoteButton=elById("downvote");const reportButton=elById("report");const keys=(()=>{let k=new URLSearchParams(params).get("keys");if(!(k&&k.length))
+function startQuotes(){const nextButton=elById("next");const upvoteButton=elById("upvote");const downvoteButton=elById("downvote");const reportButton=elById("report");const thisQuoteId=[elById("top").getAttribute("quote-id")];const nextQuoteId=[nextButton.getAttribute("quote-id")];const params=w.location.search;const keys=(()=>{let k=new URLSearchParams(params).get("keys");if(!(k&&k.length))
 return"WASD";if(k.length===4){return k.toUpperCase();}else{alert("Invalid keys given, using default.");return"WASD";}})();elById("wasd").innerText=(`${keys[0]} (Witzig), ${keys[2]} (Nicht Witzig), `
 +`${keys[1]} (Vorheriges) und ${keys[3]} (Nächstes)`);d.onkeydown=(event)=>{switch(event.code){case`Key${keys[0]}`:upvoteButton.click();break;case`Key${keys[1]}`:w.history.back();break;case`Key${keys[2]}`:downvoteButton.click();break;case`Key${keys[3]}`:nextButton.click();}};const shareButton=elById("share");const downloadButton=elById("download");const author=elById("author");const quote=elById("quote");const realAuthor=elById("real-author-name");const ratingText=elById("rating-text");const ratingImageContainer=elById("rating-img-container");nextButton.removeAttribute("href");function updateQuoteId(quoteId){shareButton.href=fixHref(`/zitate/share/${quoteId}${params}`);downloadButton.href=fixHref(`/zitate/${quoteId}.gif${params}`);const[q_id,a_id]=quoteId.split("-",2);quote.href=fixHref(`/zitate/info/z/${q_id}${params}`);author.href=fixHref(`/zitate/info/a/${a_id}${params}`);thisQuoteId[0]=quoteId;}
 function updateRating(rating){rating=rating.toString()
@@ -15,4 +15,6 @@ updateRating(data["rating"]);updateVote(Number.parseInt(data["vote"]));return tr
 w.PopStateHandlers["quotes"]=(event)=>(event.state&&handleData(event.state))
 nextButton.onclick=()=>get(`/api/zitate/${nextQuoteId[0]}`,params,(data)=>{if(!handleData(data))return;data["stateType"]="quotes";data["url"]=`/zitate/${data["id"]}${params}`;w.history.pushState(data,"Falsche Zitate",data["url"])
 w.lastLocation=data["url"];});const vote=(vote)=>post(`/api/zitate/${thisQuoteId[0]}`,{"vote":vote},(data)=>handleData(data));for(const voteButton of[upvoteButton,downvoteButton]){voteButton.type="button";voteButton.onclick=()=>{upvoteButton.disabled=true;downvoteButton.disabled=true;vote(voteButton.value);upvoteButton.disabled=false;downvoteButton.disabled=false;}}}
+for(let autoSubmitEl of document.getElementsByClassName("auto-submit-element")){autoSubmitEl.onchange=()=>autoSubmitEl.form.submit();}
+startQuotes();
 // @license-end
