@@ -54,14 +54,13 @@ function dynLoadOnData(data, onpopstate) {
     }
     if (data["scripts"]) {
         for (const script of data["scripts"]) {
-            const scriptElement = d.createElement("script");
-            if (script["src"])
+            if (script["src"]) {
+                const scriptElement = d.createElement("script");
                 scriptElement.src = script["src"];
-            if (script["script"])
-                scriptElement.innerHTML = script["script"];
-            if (script["onload"])
-                scriptElement.onload = () => eval(script["onload"]);
-            bodyDiv.appendChild(scriptElement);
+                bodyDiv.appendChild(scriptElement);
+            } else {
+                error("Script without src", script);
+            }
         }
     }
 
@@ -70,7 +69,8 @@ function dynLoadOnData(data, onpopstate) {
     d.title = data["title"];
     const titleElement = elById("title");
     titleElement.setAttribute(
-        "short_title", data["short_title"] || data["title"]
+        "short_title",
+        data["short_title"] || data["title"]
     );
     titleElement.innerText = data["title"];
 
@@ -88,21 +88,22 @@ function dynLoadReplaceHrefOnAnchor(anchor) {
     if (anchor.hasAttribute("no-dynload"))
         return;
 
-    anchor.href = dynLoadGetFixedHref(anchor.href);
+    dynLoadFixHref(anchor);
 }
 
-function dynLoadGetFixedHref(url) {
+function dynLoadFixHref(anchor) {
+    if (anchor.target === "_blank") return;
+
     const href = (
-        url.startsWith("/")
-        ? (w.location.origin + url)
-        : url
+        anchor.href.startsWith("/")
+        ? (w.location.origin + anchor.href)
+        : anchor.href
     ).trim();
+
     const hrefWithoutQuery = href.split("?")[0];
     if (
-        // already dealt with
-        href.startsWith("javascript:")
         // link is to different domain
-        || !href.startsWith(w.location.origin)
+        !href.startsWith(w.location.origin)
         // link is to file, not html page
         || (
             hrefWithoutQuery.split("/").pop().includes(".")
@@ -111,14 +112,18 @@ function dynLoadGetFixedHref(url) {
         )
         // link is to /chat, which redirects to another page
         || hrefWithoutQuery === (w.location.origin + "/chat")
-    ) return href;
+    ) return;
 
     if ( // is url to the same page, but with hash
         href.startsWith("#")
         || href.startsWith(w.location.href.split("#")[0] + "#")
-    ) return href;
+    ) return;
 
-    return `javascript:dynLoad("${href.replace(/"/g, '%22')}");`;
+    // TODO: this broken because CSP
+    anchor.onclick = (e) => {
+        dynLoad(href);
+        e.preventDefault();
+    }
 }
 
 function dynLoad(url) {
@@ -187,4 +192,6 @@ function dynLoadOnPopState(event) {
 }
 
 w.PopStateHandlers["dynLoad"] = dynLoadOnPopState;
+
+dynLoadReplaceAnchors();
 // @license-end
