@@ -42,7 +42,6 @@ import orjson as json
 import yaml
 from accept_types import get_best_match  # type: ignore
 from ansi2html import Ansi2HTMLConverter  # type: ignore
-from blake3 import blake3  # type: ignore
 from bs4 import BeautifulSoup
 from dateutil.easter import easter
 from elasticsearch import AsyncElasticsearch
@@ -70,6 +69,7 @@ from .utils import (
     anonymize_ip,
     bool_to_str,
     geoip,
+    hash_bytes_b64,
     normalized_levenshtein,
     replace_umlauts,
     str_to_bool,
@@ -118,9 +118,10 @@ class BaseRequestHandler(RequestHandler):
     short_title: str = "Asoziales Netzwerk"
     description: str = "Die tolle Webseite des Asozialen Netzwerkes"
     content_type: None | str = None
-    _active_origin_trials: set[str]
-    _auth_failed: bool = False
+    active_origin_trials: set[bytes]
+    auth_failed: bool = False
     now: datetime
+    apm_script: None | str
 
     def initialize(
         self,
@@ -175,15 +176,49 @@ class BaseRequestHandler(RequestHandler):
         """Get the Elastic APM client from the settings."""
         return self.settings.get("ELASTIC_APM_CLIENT")
 
+    def set_csp_header(self) -> None:
+        """Set the Content-Security-Policy header."""
+        script_src = ["'self'"]
+        if self.elastic_apm_enabled():
+            script_src.append(
+                f"'sha256-{self.settings['ELASTIC_APM']['INLINE_SCRIPT_HASH']}'"
+            )
+        self.set_header(
+            "Content-Security-Policy",
+            "default-src 'self';"
+            f"script-src {' '.join(script_src)};"
+            "style-src 'self' 'unsafe-inline';"
+            "img-src 'self' https://img.zeit.de https://github.asozial.org;"
+            "report-to default;"
+            + (
+                f"report-uri {self.get_reporting_api_endpoint()};"
+                if self.settings.get("REPORTING")
+                else ""
+            )
+            + (
+                f"connect-src 'self' {self.settings['ELASTIC_APM']['SERVER_URL']};"
+                if self.elastic_apm_enabled()
+                else ""
+            ),
+        )
+
+    def get_reporting_api_endpoint(self) -> None | str:
+        """Get the endpoint for the reporting API."""
+        if not self.settings.get("REPORTING"):
+            return None
+        endpoint = self.settings.get("REPORTING_ENDPOINT")
+
+        if not endpoint or not endpoint.startswith("/"):
+            return endpoint
+
+        return f"{self.request.protocol}://{self.request.host}{endpoint}"
+
     def set_default_headers(self) -> None:
         """Set default headers."""
-        self._active_origin_trials = set()
+        self.set_csp_header()
+        self.active_origin_trials = set()
         if self.settings.get("REPORTING"):
-            endpoint = self.settings.get("REPORTING_ENDPOINT")
-            if endpoint and endpoint.startswith("/"):
-                endpoint = (
-                    f"{self.request.protocol}://{self.request.host}{endpoint}"
-                )
+            endpoint = self.get_reporting_api_endpoint()
             self.set_header("Reporting-Endpoints", f'default="{endpoint}"')
             self.set_header(
                 "Report-To",
@@ -205,25 +240,6 @@ class BaseRequestHandler(RequestHandler):
             "Access-Control-Allow-Methods",
             ", ".join(self.get_allowed_methods()),
         )
-        self.set_header(
-            "Content-Security-Policy",
-            "default-src 'self';"
-            "script-src 'self' 'unsafe-inline';"
-            "style-src 'self' 'unsafe-inline';"
-            "img-src 'self' https://img.zeit.de https://github.asozial.org;"
-            "report-to default;"
-            + (
-                f"report-uri {endpoint};"
-                if self.settings.get("REPORTING")
-                else ""
-            )
-            + (
-                f"connect-src 'self' {self.settings['ELASTIC_APM']['SERVER_URL']};"
-                if "ELASTIC_APM" in self.settings
-                and self.settings["ELASTIC_APM"]["ENABLED"]
-                else ""
-            ),
-        )
         # opt out of all FLoC cohort calculation
         self.set_header("Permissions-Policy", "interest-cohort=()")
         # don't send the Referer header for cross-origin requests
@@ -263,20 +279,21 @@ class BaseRequestHandler(RequestHandler):
                         f"X-Permission-{permission.name}",
                         bool_to_str(bool(self.is_authorized(permission))),
                     )
-        if self._auth_failed:
+        if self.auth_failed:
             self.set_header("WWW-Authenticate", "Bearer")
         self.origin_trial(
             "AjM7i7vhQFI2RUcab3ZCsJ9RESLDD9asdj0MxpwxHXXtETlsm8dEn+HSd646oPr1dKjn+EcNEj8uV3qFGJzObgsAAAB3eyJvcmlnaW4iOiJodHRwczovL2Fzb3ppYWwub3JnOjQ0MyIsImZlYXR1cmUiOiJTZW5kRnVsbFVzZXJBZ2VudEFmdGVyUmVkdWN0aW9uIiwiZXhwaXJ5IjoxNjg0ODg2Mzk5LCJpc1N1YmRvbWFpbiI6dHJ1ZX0="  # noqa: B950  # pylint: disable=line-too-long, useless-suppression
         )
 
-    def origin_trial(self, token: str | bytes) -> bool:
+    def origin_trial(self, token: bytes | str) -> bool:
         """Enable an experimental feature."""
         # pylint: disable=protected-access
-        if token in self._active_origin_trials:
-            return True
-        url = urlsplit(self.request.full_url())
-        payload = json.loads(b64decode(token)[69:])
+        data = b64decode(token)
+        payload = json.loads(data[69:])
         origin = urlsplit(payload["origin"])
+        url = urlsplit(self.request.full_url())
+        if data in self.active_origin_trials:
+            return True
         if url.port is None and url.scheme in {"http", "https"}:
             url = url._replace(
                 netloc=f"{url.hostname}:{443 if url.scheme == 'https' else 80}"
@@ -291,9 +308,7 @@ class BaseRequestHandler(RequestHandler):
         ):
             return False
         self.add_header("Origin-Trial", token)
-        self._active_origin_trials.add(
-            token if isinstance(token, str) else token.decode("ascii")
-        )
+        self.active_origin_trials.add(data)
         return True
 
     def set_cookie(  # pylint: disable=too-many-arguments
@@ -411,13 +426,19 @@ class BaseRequestHandler(RequestHandler):
         self.content_type = content_type
         self.set_content_type_header()
 
+    def elastic_apm_enabled(self) -> bool:
+        """Return whether elastic apm is enabled."""
+        return (
+            "ELASTIC_APM" in self.settings
+            and self.settings["ELASTIC_APM"]["ENABLED"]
+        )
+
     async def prepare(  # noqa: C901
         self,
     ) -> None:
         """Check authorization and call self.ratelimit()."""
         # pylint: disable=invalid-overridden-method, too-complex
         self.now = await self.get_time()
-
         self.handle_accept_header(self.POSSIBLE_CONTENT_TYPES)
 
         if self.request.method == "GET":
@@ -444,7 +465,7 @@ class BaseRequestHandler(RequestHandler):
             if required_permission is not None:
                 is_authorized = self.is_authorized(required_permission)
                 if not is_authorized:
-                    self._auth_failed = True
+                    self.auth_failed = True
                     logger.warning(
                         "Unauthorized access to %s from %s",
                         self.request.path,
@@ -492,9 +513,9 @@ class BaseRequestHandler(RequestHandler):
             or self.is_authorized(Permission.RATELIMITS)
         ):
             return False
-        remote_ip = blake3(
+        remote_ip = hash_bytes_b64(
             cast(str, self.request.remote_ip).encode("ascii")
-        ).hexdigest()
+        )
         method = self.request.method
         if method == "HEAD":
             method = "GET"
@@ -552,8 +573,7 @@ class BaseRequestHandler(RequestHandler):
             self.set_header("X-RateLimit-Reset", str(time.time() + reset_after))
             self.set_header("X-RateLimit-Reset-After", str(reset_after))
             self.set_header(
-                "X-RateLimit-Bucket",
-                blake3(bucket.encode("ascii")).hexdigest(),
+                "X-RateLimit-Bucket", hash_bytes_b64(bucket.encode("ascii")),
             )
         # fmt: on
         if result[0]:
@@ -975,6 +995,9 @@ class HTMLRequestHandler(BaseRequestHandler):
             short_title=self.short_title,
             theme=self.get_display_theme(),
             title=self.title,
+            apm_script=self.settings["ELASTIC_APM"]["INLINE_SCRIPT"]
+            if self.elastic_apm_enabled()
+            else None,
         )
         namespace.update(
             {
@@ -1033,8 +1056,8 @@ class HTMLRequestHandler(BaseRequestHandler):
             scripts=[
                 {
                     "src": _s.get("src"),
-                    "script": _s.string,
-                    "onload": _s.get("onload"),
+                    # "script": _s.string,  # not in use because of csp
+                    # "onload": _s.get("onload"),  # not in use because of csp
                 }
                 for _s in soup.find_all("script")
             ]
@@ -1127,7 +1150,8 @@ class NotFoundHandler(HTMLRequestHandler):
             "/wp-login",
             "/wp-upload",
         }:
-            raise HTTPError(469, reason="Nice Try")
+            self.set_status(469, reason="Nice Try")
+            return self.write_error(469)
 
         if new_path != self.request.path:
             return self.redirect(self.fix_url(new_path=new_path), True)
@@ -1165,7 +1189,6 @@ class NotFoundHandler(HTMLRequestHandler):
         if len(distances) > 0:
             # sort to get the one with the smallest distance in index 0
             distances.sort()
-            print(distances)
             dist, path = distances[0]
             # redirect only if the distance is less than or equal {max_dist}
             if dist <= max_dist:
@@ -1183,10 +1206,15 @@ class ErrorPage(HTMLRequestHandler):
     async def get(self, code: str) -> None:
         """Show the error page."""
         status_code: int = int(code)
-        reason: str = responses.get(status_code, "")  # get the reason
-        # set the status code if Tornado doesn't raise an error if it is set
+        if status_code == 420:
+            reason = "Enhance Your Calm"
+        elif status_code == 469:
+            reason = "Nice Try"
+        else:
+            reason = responses.get(status_code, "")
+        # set the status code if it is allowed
         if status_code not in (204, 304) and not 100 <= status_code < 200:
-            self.set_status(status_code)  # set the status code
+            self.set_status(status_code, reason)
         return await self.render(
             "error.html",
             status=status_code,
